from . import check_local_user_enviroment
from . import first_run_setup
from . import nextcloud_activities
from . import nextcloud_file_operations
from . import nextcloud_talk_extractor
from . import nextcloud_user
from . import read_data
from . import send_message
from . import translations
from . import headers
from . import nextcloud_requests
from . import permissions_map


class NextcloudTalkBot:
    def __init__(self):
        pass
